#include "main.h"

//***********************************************
//* Function: Initialize A/D                    *
//*        - Fosc/32 clock source, Tad=2uS      *
//*        - Right justified                    *
//*        - 2 Analog Input:AN0, AN1			*
//*		   - Ext. V.Ref : Vref+ AN3, Vref- Vss	*
//*        - Input Channel : VH0 & CH1          *
//*        - Disable A/D interrupt              *
//***********************************************
void InitializeAD(void)
{
	ADCON1 = 0b00011101;   	// Enable AN0, AN1 are ADC input, Vref+ = 3.3V External, Vref- =Vss
	ADCON0 = 0b00000001;	// A/D ON , Select Channel = AN0
	ADCON2 = 0b10111111;	// Vkվ,ˮɶ 20 Tad, Tad=  ADC RC 

	PIE1bits.ADIE=0;		// Disable A/D interrupt
}

//************************************************
//* Initial I2C Master Mode with 7 bits Address  *
//* Clock Speed : 100KHz @16MHz					 *
//************************************************
void Initialize_I2C_Master(void)
{
	TRISCbits.TRISC3=1;
	TRISCbits.TRISC4=1;
	OpenI2C(MASTER,SLEW_ON);
	SSPADD= 39;
	SSPSTATbits.CKE=1;				// SMBus specific inputs
} 

//************************************************
//* Function: Initialize Interrupts              *
//*   - Reset All Interrupr                      *
//*   - Enable HIgh Priority Interrupt           *
//*   - Disable Low Priority Interrupt           *
//************************************************
void InitializeINTs(void) 
{
 	PIR1=0; 						//Clear all Interrupt setting & Flag
	PIR2=0;
	INTCON=0;
	INTCON2=0;
	INTCON3=0;
	PIE1=0;
	PIE2=0;

	RCONbits.IPEN=1;     			//Enable priority interrupts
	INTCONbits.GIEL=1;				// Enable Low Priority Interrupt
	INTCONbits.GIEH=1;				// Enalbe high priority Interrupt
}

//************************************************
//*        Function: Initialize Timer1           *
//************************************************
void InitializeTMR1(void)
{

	OpenTimer1(	TIMER_INT_ON&T1_16BIT_RW
					&T1_SOURCE_EXT&T1_PS_1_1
					&T1_OSC1EN_ON&T1_SYNC_EXT_ON);
	
 	WriteTimer1(65536-16384 ) ;

	IPR1bits.TMR1IP=0;						// Set Timer1 for Low Priority Interrupt
	PIR1bits.TMR1IF=0;						// Clear Interrupt flag of Timer 1
	
	PIE1bits.TMR1IE=1;						// Enable Timer1 Interrupt
}


//************************************************
//*        Function: Initialize PORT             *
//************************************************
void InitializePORT(void)
{

	PORTA=0x00;
	TRISA=0b11011011;				// RA0 & RA1 as A/D input,RA4 as SW2 input
									// RA2 as LCD-E control, RA5 as CS Control  for SPI
	PORTB=0x00;
	TRISB=0b11001001;				// RB[6:7] as ICD2, 
									// RB2 as CANTX , RB3 as CANRX
	PORTC=0x00;
	
	PORTD=0x00;
}
//************************************************
//* Function: Initialize USART                   *
//*   - Initialize the RS-232 communication      *
//*   - Disable Interrupr for TxD                *
//*   - Enable Interrupt fro Rxd                 *
//*   - Format: 19200, N, 8, 1                    *
//************************************************
void InitializeUSART(void)
{
	TRISCbits.TRISC7=1;				// Set input for RXD
	TRISCbits.TRISC6=0;				// Set output for TXD
	RCSTAbits.SPEN=1;				// Enable USART Module	
	
	OpenUSART(  USART_TX_INT_OFF 	// Set TXSTA Reg. =0b00100100 
		 	  & USART_RX_INT_ON		// Set RCSTA Reg. =0b10010000 
		 	  & USART_ASYNCH_MODE
		 	  & USART_EIGHT_BIT
		 	  & USART_CONT_RX
		 	  & USART_BRGH_HIGH
		 	  ,51);					// Set SPBRG=51, Baud Rate = 19200 @16MHz

	IPR1bits.RCIP=1;       			// Set Receive of USART are High priority
	PIE1bits.RCIE=1;				// Enable RxD Interrupt
}
