#include "main.h"

//*************************************************************************
//         This first function is for the TC74A7 tempturature sensor
//
//  1st.  Check if tempturature sensor is ready to be read in config Reg.
//  2nd.  If ready, receive the temperature data with Hex.
//*************************************************************************
//         This second function is for the TC1047A tempturature sensor
//
//  1st.  Read the analog voltage for TC1074A output
//  2nd.  Convert the analog voltage to temperature code
//*************************************************************************      

extern near union
{
	unsigned char Flag;	
	struct {
			unsigned Key_Flag:1;
    		unsigned Timer1_Flag:1;
    		unsigned SW2_Flag:1;
			unsigned Buzzer_On_Flag:1;
			unsigned Buzzer_Fast_Flag:1;
			unsigned Buzzer_Mid_Flag:1;
			unsigned Buzzer_Slow_Flag:1;
			unsigned Shutdown_Flag:1;
    		};		
} Flagbits;

union
{
	int	Word;
	unsigned char Byte[2];

	struct{
			unsigned:6 ;
			unsigned BitD6:1;
		   };
} TC_74;

#define TC74_Addr	0b10011110			// Define the TC74-A7 address with write command
#define TC74_RWCR	0x01				// Define the Read/Write Configuration Command
#define TC74_RTR	0x00				// Define the read temperature command

//*********************************************************** 
//***      Read a Temperature Hex Value for the TC74     ****
//*********************************************************** 
//* The function will read a configuration register first.	*
//* Check the Data Ready bit (b6) in the Config Reg.		*
//* B6=0, Not Ready, Return (-2)						 	*
//* B6=1, Data is Ready, read the temperature value			*
//*															*
//* Return Value = >0 ; Normal Temperature Read				*
//* Return Value = -1 ; Fail to read temperature			*
//* Return Value = -2 ; TC74-A7 device is not ready			* 
//*															*
//*  TC74 Accuracy +-2C , From 25C~85C						*
//*  Out Hex Value :  0C --> 0x00		  1C --> 0x01		*
//*					 25C --> 0x19		127C --> 0x7F		*
//*					-25C --> 0xE7		-55C --> 0xC9		*
//*********************************************************** 

unsigned Read_TC74_Temperature(void)
{
	TC_74.Word = 0 ;		

	TC_74.Word=EERandomRead(TC74_Addr,TC74_RWCR); 	// Read Status from TC74-A7

	if ( TC_74.BitD6 )								// b6 =1 , Read temperature
	{
		TC_74.Word=(EERandomRead(TC74_Addr,TC74_RTR)+2);

		if ( TC_74.Word >= 0 ) return TC_74.Word;
		else return -1;								// Read Fail, return (-1)
	}
	else return -2;									// b6=0, return (-2)					
}

//***************************************************************
//***       Read a Temperature Sensor for the TC1047A        ****
//***************************************************************
//* The TC1047A is linear voltage output temperature sensor		*
//* 												 			*
//*    The output voltage is typically 10mV/C voltage slope		*
//*	100mV at -40C, 500mV at 0C, 750mV at +25C, 1750mV at +125C.	*
//*																*
//* The curcuit design is for the measure temperature range 	*
//* from 0C to 100C, the output reault form the OP amp are		*
//*    0C = -0.72V * 2.3 + (0.5V+(10mV * 0C)) * 3.3 = 0.006V	*
//*  100C = -0.72V * 2.3 + (0.5V+(10mV*100C)) * 3.3 = 3.294V	* 
//*************************************************************** 

int Read_TC1047_Temperature(void)
{
	unsigned char ADCON1_Temp;
	int	AD_Temp;

//*************************************************************************
//*        Ū TC1047A ū׭
//* 1. ƥReturn^Ƿū׭(10-bit)
//* 2. ]wū׿J CH1, եū׽d CH0 (VR J)
//* 3. CHܶ20uSHW(Sample hold)
//* 4. ϥ AN3 ~ѦҹqJ}ɡALCD  E } (AN2)npBz
//*
//**************************************************************************

		ADCON1_Temp = ADCON1;   // ] AN2  LCM  E }AȮɤ AN2

		ADCON1 = 0b00011011;   	// Enable AN0, AN1, AN2 & AN3 are ADC input
								// Vref+ = AN3 (3.30V (APP001 V3a) or 4.096V (APP001 v1.0)), Vref- = Vss
//		ADCON0bits.CHS0=1;								// Read A/D from CH1 (T2 Xq 0V ~ 3.3V)
// 		ADCON0bits.CHS0=0;								// Read A/D from CH0 (VR1 q 0 ~ 5V)

		if (Flagbits.SW2_Flag) ADCON0bits.CHS0=1;		// Ū TC1047A ū׹q
 		else ADCON0bits.CHS0=0;							// եΡAŪ VR1 qHեūתJ

		for (AD_Temp=0;AD_Temp<5;AD_Temp++);			// Delay 20uS for CH change

		ADCON0bits.GO=1;								// Start to convert the A/D
		while(ADCON0bits.GO);							// Waiting A/D until done

		AD_Temp = ReadADC( );							// Get 10 bits A/D result

		ADCON1 = ADCON1_Temp;	// ADC ഫA AN2  LCM T E
		return AD_Temp;
}
